Interactive Tutorials
=====================

If you're new to Python or simply want to quickly explore the basic features of MetaSynth, you can try one of the following interactive tutorials. They provide a step-by-step walkthrough and example dataset to help you get started. At the moment, there are two interactive tutorials available. A basic and an advanced one. Both will take you through the process of :doc:`/usage/generating_metaframes`, :doc:`/usage/exporting_metaframes`,  and :doc:`/usage/generating_synthetic_data`. The advanced tutorial provides a more in-depth look at customizing the handling of columns to generate cleaner synthetic data tailored to your use case.

Basic:
   - Binder: `Open in Binder <https://mybinder.org/v2/gh/sodascience/metasynth/HEAD?labpath=examples%2Fgetting_started.ipynb>`__
   - Google Colab: `Open in Google Colab <https://colab.research.google.com/github/sodascience/metasynth/blob/main/examples/getting_started.ipynb>`__
   - GitHub: `View on GitHub <https://github.com/sodascience/metasynth/blob/main/examples/getting_started.ipynb>`__

Advanced: 
   - Binder: `Open in Binder <https://mybinder.org/v2/gh/sodascience/metasynth/HEAD?labpath=examples%2Fadvanced_tutorial.ipynb>`__
   - Google Colab: `Open in Google Colab <https://colab.research.google.com/github/sodascience/metasynth/blob/main/examples/advanced_tutorial.ipynb>`__
   - GitHub: `View on GitHub <https://github.com/sodascience/metasynth/blob/main/examples/advanced_tutorial.ipynb>`__
